@@ -35,8 +35,8 @@ __author__ = "Alexander Bisland"
 __version__ = "1.0.2"
 supported_from = "3.8.1"
 
-import ImageReader
-import AdvancedImageReader
-import SimpleImageReader
-import AudioReader
-import RawReader
+from StegaSaurus.read import ImageReader
+from StegaSaurus.read import AdvancedImageReader
+from StegaSaurus.read import SimpleImageReader
+from StegaSaurus.read import AudioReader
+from StegaSaurus.read import RawReader
